@@ -36,11 +36,32 @@ e2 = EAT(h = h, type_pi="T", date_formatting = "original")
 e1.forecast(df_uni)
 e2.forecast(df_uni)
 
+print("EAT ---------- \n")
+print(e1.averages)
+print("\n")
+print(e1.ranges)
+print("\n")
+print(e2.averages)
+print("\n")
+print(e2.ranges)
+print("\n")
+
+
 e3 = DynamicRegressor(h = h, date_formatting = "ms")
 e4 = DynamicRegressor(h = h, date_formatting = "original")
 e3.forecast(df_uni)
 e4.forecast(df_uni)
 
+print("DynamicRegressor ---------- \n")
+print(e3.averages)
+print("\n")
+print(e3.ranges)
+print("\n")
+print(e4.averages)
+print("\n")
+print(e4.ranges)
+print("\n")
+
 e5 = Ridge2Regressor(h = h, date_formatting = "ms")
 e6 = Ridge2Regressor(h = h, date_formatting = "original")
 e5.forecast(df_multi)
